summaryrefslogtreecommitdiff
path: root/ucb/source/ucp/odma/odma_provider.hxx
diff options
context:
space:
mode:
authorTor Lillqvist <tlillqvist@novell.com>2010-08-25 22:28:03 +0200
committerJan Holesovsky <kendy@suse.cz>2010-08-26 13:08:23 +0200
commite63de186d0e900fa24e4e34ccda5434b83de3d7a (patch)
treec4449c8c8a7958236fd59848f6375fc64dfe5246 /ucb/source/ucp/odma/odma_provider.hxx
parent47c333a0f61a5d91c1379f4b6aac58e5505735d4 (diff)
novell-win32-odma.diff: ODMA dialog implementation.
i#6885, i#32741
Diffstat (limited to 'ucb/source/ucp/odma/odma_provider.hxx')
-rw-r--r--ucb/source/ucp/odma/odma_provider.hxx15
1 files changed, 12 insertions, 3 deletions
diff --git a/ucb/source/ucp/odma/odma_provider.hxx b/ucb/source/ucp/odma/odma_provider.hxx
index cbd8e6b49f..272d5e7fbe 100644
--- a/ucb/source/ucp/odma/odma_provider.hxx
+++ b/ucb/source/ucp/odma/odma_provider.hxx
@@ -29,6 +29,8 @@
#define ODMA_PROVIDER_HXX
#include <ucbhelper/providerhelper.hxx>
+#include <tools/prewin.h>
+#include <tools/postwin.h>
#include "odma_lib.hxx"
#include "rtl/ref.hxx"
@@ -43,7 +45,7 @@ namespace odma {
// UNO service name for the provider. This name will be used by the UCB to
// create instances of the provider.
#define ODMA_CONTENT_PROVIDER_SERVICE_NAME \
- "com.sun.star.ucb.OdmaContentProvider"
+ "com.sun.star.ucb.ODMAContentProvider"
// #define ODMA_CONTENT_PROVIDER_SERVICE_NAME_LENGTH 34
// URL scheme. This is the scheme the provider will be able to create
@@ -133,14 +135,21 @@ public:
*/
::rtl::Reference<ContentProperties> queryContentProperty(const ::rtl::OUString& _sDocumentName);
- /** getContentProperty returns the ContentProperties for the first content with that title
+ /** getContentPropertyWithTitle returns the ContentProperties for the first content with that title
@param _sTitle the title of the document
@return the content properties
*/
::rtl::Reference<ContentProperties> getContentPropertyWithTitle(const ::rtl::OUString& _sTitle) const;
- /** getContentProperty returns the ContentProperties for the first content with that SavedAsName
+ /** getContentPropertyWithDocumentId returns the ContentProperties for the first content with that title
+ @param _sTitle the title of the document
+
+ @return the content properties
+ */
+ ::rtl::Reference<ContentProperties> getContentPropertyWithDocumentId(const ::rtl::OUString& _sDocumentId) const;
+
+ /** getContentPropertyWithSavedAsName returns the ContentProperties for the first content with that SavedAsName
@param _sSaveAsName the SavedAsName of the document
@return the content properties